@@ -21,7 +21,7 @@ from .util import Print, VERBOSITY, Preproc as Pp
 from functools import reduce
 from six.moves import xrange
 
-__version__ = "0.5.5"
+__version__ = "0.5.6"
 
 ENCODING = "utf-8"
 
@@ -752,7 +752,7 @@ class SS3:
                 )
                 f = open(voc_path, "w+", encoding=ENCODING)
                 vocabularies_out[ilen].sort(key=lambda k: -k[-1])
-                f.write(u"%s,%s,%s,%s\n" % ("term", "fr", "gv", "norm_gv"))
+                f.write(u"%s,%s,%s,%s\n" % ("term", "fr", "gv", "cv"))
                 for trans in vocabularies_out[ilen]:
                     f.write(u"%s,%d,%f,%f\n" % tuple(trans))
                 f.close()
@@ -1904,11 +1904,8 @@ class SS3:
             doc = doc.encode(ENCODING).decode(ENCODING)
         except AttributeError:
             pass
-        try:
-            icat = self.__get_category__(cat)
-        except AttributeError:
-            icat = self.__get_category__(cat)
 
+        icat = self.__get_category__(cat)
         cat = self.__categories__[icat]
         word_to_index = self.__word_to_index__
 
@@ -2007,13 +2004,15 @@ class SS3:
                   If ``sort`` is True, a list of pairs
                   (category index, confidence value) ordered by confidence value.
         :rtype: list
+        :raises: EmptyModelError
         """
-        if not self.__categories__ or not doc:
-            return []
+        if not self.__categories__:
+            raise EmptyModelError
 
         if self.__update_needed__():
             self.update_values()
 
+        doc = doc or ''
         try:
             doc = doc.decode(ENCODING)
         except UnicodeEncodeError:  # for python 2 compatibility
@@ -2597,3 +2596,6 @@ SS3.set_alpha = SS3.set_a
 SS3.get_alpha = SS3.get_a
 SS3.get_alpha = SS3.get_a
 SS3.train = SS3.fit
+SS3.save = SS3.save_model
+SS3.load = SS3.load_model
+SS3.update = SS3.update_values
